@@ -22,6 +22,8 @@
 extern "C" {
 #endif
 
+#define CCMaxMetrics  3
+
 typedef struct _CCObjectInfo
 {
   ssize_t
@@ -42,6 +44,9 @@ typedef struct _CCObjectInfo
 
   MagickBooleanType
     merge;
+
+  double
+    metric[CCMaxMetrics];
 } CCObjectInfo;
 
 extern MagickExport Image
